@@ -31,7 +31,8 @@ def check_url(arg, wlist, verb):
         print('Sorry, can\'t open {}. Are you sure it exists?'.format(arg))
         return
     check = analysis.Checktext(arg, wlist, verb, False)
-    check.run_check(data.encode('utf-8'))
+    result = check.run_check(data.encode('ascii', 'ignore'))
+    check.fmt_output(*result)
 
 def check_file(arg, wlist, verb):
     exts = ('.docx', '.odt', '.ods', '.odp')
@@ -40,13 +41,14 @@ def check_file(arg, wlist, verb):
         data = doc_reader.get_doctype()
     else:
         try:
-            with open(arg, 'rb') as f:
-                data = f.read()
+            with open(arg) as f:
+                data = f.read().encode('ascii', 'ignore')
         except:
             print('Sorry, can\'t open {}. Are you sure it exists?'.format(arg))
             return
     check = analysis.Checktext(arg, wlist, verb, False)
-    check.run_check(data)
+    result = check.run_check(data)
+    check.fmt_output(*result)
 
 @click.command()
 @click.argument('filename', required=sys.stdin.isatty(), nargs=-1)
@@ -63,7 +65,7 @@ def cli(filename, wordlist, verbose):
         with sys.stdin as f:
             filename = [arg.strip() for arg in f]
     for arg in filename:
-        if arg.startswith('http'):
+        if arg.startswith(('http', 'ftp')):
             check_url(arg, wordlist, verbose)
         else:
             check_file(arg, wordlist, verbose)
